# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)
from casedev.types.agent.v2.chat import FileListResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFiles:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        file = client.agent.v2.chat.files.list(
            "id",
        )
        assert_matches_type(FileListResponse, file, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.agent.v2.chat.files.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(FileListResponse, file, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.agent.v2.chat.files.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(FileListResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.agent.v2.chat.files.with_raw_response.list(
                "",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_download(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/agent/v2/chat/id/files/filePath").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        file = client.agent.v2.chat.files.download(
            file_path="filePath",
            id="id",
        )
        assert file.is_closed
        assert file.json() == {"foo": "bar"}
        assert cast(Any, file.is_closed) is True
        assert isinstance(file, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_download(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/agent/v2/chat/id/files/filePath").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        file = client.agent.v2.chat.files.with_raw_response.download(
            file_path="filePath",
            id="id",
        )

        assert file.is_closed is True
        assert file.http_request.headers.get("X-Stainless-Lang") == "python"
        assert file.json() == {"foo": "bar"}
        assert isinstance(file, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_download(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/agent/v2/chat/id/files/filePath").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        with client.agent.v2.chat.files.with_streaming_response.download(
            file_path="filePath",
            id="id",
        ) as file:
            assert not file.is_closed
            assert file.http_request.headers.get("X-Stainless-Lang") == "python"

            assert file.json() == {"foo": "bar"}
            assert cast(Any, file.is_closed) is True
            assert isinstance(file, StreamedBinaryAPIResponse)

        assert cast(Any, file.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_path_params_download(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.agent.v2.chat.files.with_raw_response.download(
                file_path="filePath",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            client.agent.v2.chat.files.with_raw_response.download(
                file_path="",
                id="id",
            )


class TestAsyncFiles:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        file = await async_client.agent.v2.chat.files.list(
            "id",
        )
        assert_matches_type(FileListResponse, file, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.agent.v2.chat.files.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(FileListResponse, file, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.agent.v2.chat.files.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(FileListResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.agent.v2.chat.files.with_raw_response.list(
                "",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_download(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/agent/v2/chat/id/files/filePath").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        file = await async_client.agent.v2.chat.files.download(
            file_path="filePath",
            id="id",
        )
        assert file.is_closed
        assert await file.json() == {"foo": "bar"}
        assert cast(Any, file.is_closed) is True
        assert isinstance(file, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_download(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/agent/v2/chat/id/files/filePath").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        file = await async_client.agent.v2.chat.files.with_raw_response.download(
            file_path="filePath",
            id="id",
        )

        assert file.is_closed is True
        assert file.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await file.json() == {"foo": "bar"}
        assert isinstance(file, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_download(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/agent/v2/chat/id/files/filePath").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        async with async_client.agent.v2.chat.files.with_streaming_response.download(
            file_path="filePath",
            id="id",
        ) as file:
            assert not file.is_closed
            assert file.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await file.json() == {"foo": "bar"}
            assert cast(Any, file.is_closed) is True
            assert isinstance(file, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, file.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_path_params_download(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.agent.v2.chat.files.with_raw_response.download(
                file_path="filePath",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            await async_client.agent.v2.chat.files.with_raw_response.download(
                file_path="",
                id="id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SpeakCreateParams", "VoiceSettings"]


class SpeakCreateParams(TypedDict, total=False):
    text: Required[str]
    """Text to convert to speech"""

    apply_text_normalization: bool
    """Apply automatic text normalization"""

    enable_logging: bool
    """Enable request logging"""

    language_code: str
    """Language code for multilingual models"""

    model_id: Literal["eleven_multilingual_v2", "eleven_turbo_v2", "eleven_monolingual_v1"]
    """ElevenLabs model ID"""

    next_text: str
    """Next context for better pronunciation"""

    optimize_streaming_latency: int
    """Optimize for streaming latency (0-4)"""

    output_format: Literal["mp3_44100_128", "mp3_44100_192", "pcm_16000", "pcm_22050", "pcm_24000", "pcm_44100"]
    """Audio output format"""

    previous_text: str
    """Previous context for better pronunciation"""

    seed: int
    """Seed for reproducible generation"""

    voice_id: str
    """ElevenLabs voice ID (defaults to Rachel - professional, clear)"""

    voice_settings: VoiceSettings
    """Voice customization settings"""


class VoiceSettings(TypedDict, total=False):
    """Voice customization settings"""

    similarity_boost: float
    """Similarity boost (0-1)"""

    stability: float
    """Voice stability (0-1)"""

    style: float
    """Style exaggeration (0-1)"""

    use_speaker_boost: bool
    """Enable speaker boost"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["V1GetCitationsFromURLParams"]


class V1GetCitationsFromURLParams(TypedDict, total=False):
    url: Required[str]
    """URL of the legal document to extract citations from"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)
from casedev.types.vault import (
    ObjectListResponse,
    ObjectDeleteResponse,
    ObjectUpdateResponse,
    ObjectGetTextResponse,
    ObjectRetrieveResponse,
    ObjectGetOcrWordsResponse,
    ObjectGetSummarizeJobResponse,
    ObjectCreatePresignedURLResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestObjects:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: Casedev) -> None:
        object_ = client.vault.objects.retrieve(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectRetrieveResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.retrieve(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectRetrieveResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.retrieve(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectRetrieveResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.retrieve(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.retrieve(
                object_id="",
                id="id",
            )

    @parametrize
    def test_method_update(self, client: Casedev) -> None:
        object_ = client.vault.objects.update(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

    @parametrize
    def test_method_update_with_all_params(self, client: Casedev) -> None:
        object_ = client.vault.objects.update(
            object_id="objectId",
            id="id",
            filename="deposition-smith-2024.pdf",
            metadata={},
            path="/Discovery/Depositions",
        )
        assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_update(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.update(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_update(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.update(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.update(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.update(
                object_id="",
                id="id",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        object_ = client.vault.objects.list(
            "id",
        )
        assert_matches_type(ObjectListResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectListResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectListResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.list(
                "",
            )

    @parametrize
    def test_method_delete(self, client: Casedev) -> None:
        object_ = client.vault.objects.delete(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

    @parametrize
    def test_method_delete_with_all_params(self, client: Casedev) -> None:
        object_ = client.vault.objects.delete(
            object_id="objectId",
            id="id",
            force="true",
        )
        assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.delete(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.delete(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.delete(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.delete(
                object_id="",
                id="id",
            )

    @parametrize
    def test_method_create_presigned_url(self, client: Casedev) -> None:
        object_ = client.vault.objects.create_presigned_url(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

    @parametrize
    def test_method_create_presigned_url_with_all_params(self, client: Casedev) -> None:
        object_ = client.vault.objects.create_presigned_url(
            object_id="objectId",
            id="id",
            content_type="contentType",
            expires_in=60,
            operation="GET",
            size_bytes=1,
        )
        assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_create_presigned_url(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.create_presigned_url(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_create_presigned_url(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.create_presigned_url(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_presigned_url(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.create_presigned_url(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.create_presigned_url(
                object_id="",
                id="id",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_download(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/vault/id/objects/objectId/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        object_ = client.vault.objects.download(
            object_id="objectId",
            id="id",
        )
        assert object_.is_closed
        assert object_.json() == {"foo": "bar"}
        assert cast(Any, object_.is_closed) is True
        assert isinstance(object_, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_download(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/vault/id/objects/objectId/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )

        object_ = client.vault.objects.with_raw_response.download(
            object_id="objectId",
            id="id",
        )

        assert object_.is_closed is True
        assert object_.http_request.headers.get("X-Stainless-Lang") == "python"
        assert object_.json() == {"foo": "bar"}
        assert isinstance(object_, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_download(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/vault/id/objects/objectId/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        with client.vault.objects.with_streaming_response.download(
            object_id="objectId",
            id="id",
        ) as object_:
            assert not object_.is_closed
            assert object_.http_request.headers.get("X-Stainless-Lang") == "python"

            assert object_.json() == {"foo": "bar"}
            assert cast(Any, object_.is_closed) is True
            assert isinstance(object_, StreamedBinaryAPIResponse)

        assert cast(Any, object_.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_path_params_download(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.download(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.download(
                object_id="",
                id="id",
            )

    @parametrize
    def test_method_get_ocr_words(self, client: Casedev) -> None:
        object_ = client.vault.objects.get_ocr_words(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

    @parametrize
    def test_method_get_ocr_words_with_all_params(self, client: Casedev) -> None:
        object_ = client.vault.objects.get_ocr_words(
            object_id="objectId",
            id="id",
            page=0,
            word_end=0,
            word_start=0,
        )
        assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_get_ocr_words(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.get_ocr_words(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_get_ocr_words(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.get_ocr_words(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_ocr_words(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.get_ocr_words(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.get_ocr_words(
                object_id="",
                id="id",
            )

    @parametrize
    def test_method_get_summarize_job(self, client: Casedev) -> None:
        object_ = client.vault.objects.get_summarize_job(
            job_id="jobId",
            id="id",
            object_id="objectId",
        )
        assert_matches_type(ObjectGetSummarizeJobResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_get_summarize_job(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.get_summarize_job(
            job_id="jobId",
            id="id",
            object_id="objectId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectGetSummarizeJobResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_get_summarize_job(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.get_summarize_job(
            job_id="jobId",
            id="id",
            object_id="objectId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectGetSummarizeJobResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_summarize_job(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.get_summarize_job(
                job_id="jobId",
                id="",
                object_id="objectId",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.get_summarize_job(
                job_id="jobId",
                id="id",
                object_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `job_id` but received ''"):
            client.vault.objects.with_raw_response.get_summarize_job(
                job_id="",
                id="id",
                object_id="objectId",
            )

    @parametrize
    def test_method_get_text(self, client: Casedev) -> None:
        object_ = client.vault.objects.get_text(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectGetTextResponse, object_, path=["response"])

    @parametrize
    def test_raw_response_get_text(self, client: Casedev) -> None:
        response = client.vault.objects.with_raw_response.get_text(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = response.parse()
        assert_matches_type(ObjectGetTextResponse, object_, path=["response"])

    @parametrize
    def test_streaming_response_get_text(self, client: Casedev) -> None:
        with client.vault.objects.with_streaming_response.get_text(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = response.parse()
            assert_matches_type(ObjectGetTextResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_text(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.objects.with_raw_response.get_text(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.objects.with_raw_response.get_text(
                object_id="",
                id="id",
            )


class TestAsyncObjects:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.retrieve(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectRetrieveResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.retrieve(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectRetrieveResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.retrieve(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectRetrieveResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.retrieve(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.retrieve(
                object_id="",
                id="id",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.update(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.update(
            object_id="objectId",
            id="id",
            filename="deposition-smith-2024.pdf",
            metadata={},
            path="/Discovery/Depositions",
        )
        assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.update(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.update(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectUpdateResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.update(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.update(
                object_id="",
                id="id",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.list(
            "id",
        )
        assert_matches_type(ObjectListResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectListResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectListResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.list(
                "",
            )

    @parametrize
    async def test_method_delete(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.delete(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

    @parametrize
    async def test_method_delete_with_all_params(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.delete(
            object_id="objectId",
            id="id",
            force="true",
        )
        assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.delete(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.delete(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectDeleteResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.delete(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.delete(
                object_id="",
                id="id",
            )

    @parametrize
    async def test_method_create_presigned_url(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.create_presigned_url(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

    @parametrize
    async def test_method_create_presigned_url_with_all_params(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.create_presigned_url(
            object_id="objectId",
            id="id",
            content_type="contentType",
            expires_in=60,
            operation="GET",
            size_bytes=1,
        )
        assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_create_presigned_url(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.create_presigned_url(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_create_presigned_url(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.create_presigned_url(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectCreatePresignedURLResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_presigned_url(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.create_presigned_url(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.create_presigned_url(
                object_id="",
                id="id",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_download(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/vault/id/objects/objectId/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        object_ = await async_client.vault.objects.download(
            object_id="objectId",
            id="id",
        )
        assert object_.is_closed
        assert await object_.json() == {"foo": "bar"}
        assert cast(Any, object_.is_closed) is True
        assert isinstance(object_, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_download(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/vault/id/objects/objectId/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )

        object_ = await async_client.vault.objects.with_raw_response.download(
            object_id="objectId",
            id="id",
        )

        assert object_.is_closed is True
        assert object_.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await object_.json() == {"foo": "bar"}
        assert isinstance(object_, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_download(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.get("/vault/id/objects/objectId/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        async with async_client.vault.objects.with_streaming_response.download(
            object_id="objectId",
            id="id",
        ) as object_:
            assert not object_.is_closed
            assert object_.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await object_.json() == {"foo": "bar"}
            assert cast(Any, object_.is_closed) is True
            assert isinstance(object_, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, object_.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_path_params_download(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.download(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.download(
                object_id="",
                id="id",
            )

    @parametrize
    async def test_method_get_ocr_words(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.get_ocr_words(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

    @parametrize
    async def test_method_get_ocr_words_with_all_params(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.get_ocr_words(
            object_id="objectId",
            id="id",
            page=0,
            word_end=0,
            word_start=0,
        )
        assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_get_ocr_words(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.get_ocr_words(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_get_ocr_words(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.get_ocr_words(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectGetOcrWordsResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_ocr_words(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.get_ocr_words(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.get_ocr_words(
                object_id="",
                id="id",
            )

    @parametrize
    async def test_method_get_summarize_job(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.get_summarize_job(
            job_id="jobId",
            id="id",
            object_id="objectId",
        )
        assert_matches_type(ObjectGetSummarizeJobResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_get_summarize_job(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.get_summarize_job(
            job_id="jobId",
            id="id",
            object_id="objectId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectGetSummarizeJobResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_get_summarize_job(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.get_summarize_job(
            job_id="jobId",
            id="id",
            object_id="objectId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectGetSummarizeJobResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_summarize_job(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.get_summarize_job(
                job_id="jobId",
                id="",
                object_id="objectId",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.get_summarize_job(
                job_id="jobId",
                id="id",
                object_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `job_id` but received ''"):
            await async_client.vault.objects.with_raw_response.get_summarize_job(
                job_id="",
                id="id",
                object_id="objectId",
            )

    @parametrize
    async def test_method_get_text(self, async_client: AsyncCasedev) -> None:
        object_ = await async_client.vault.objects.get_text(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(ObjectGetTextResponse, object_, path=["response"])

    @parametrize
    async def test_raw_response_get_text(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.objects.with_raw_response.get_text(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        object_ = await response.parse()
        assert_matches_type(ObjectGetTextResponse, object_, path=["response"])

    @parametrize
    async def test_streaming_response_get_text(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.objects.with_streaming_response.get_text(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            object_ = await response.parse()
            assert_matches_type(ObjectGetTextResponse, object_, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_text(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.objects.with_raw_response.get_text(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.objects.with_raw_response.get_text(
                object_id="",
                id="id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ProjectDeleteParams"]


class ProjectDeleteParams(TypedDict, total=False):
    delete_from_hosting: Annotated[bool, PropertyInfo(alias="deleteFromHosting")]
    """Whether to also delete the linked hosting project. Defaults to true."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_list_voices_params import V1ListVoicesParams as V1ListVoicesParams
from .v1_list_voices_response import V1ListVoicesResponse as V1ListVoicesResponse
from .boost_list_extract_params import BoostListExtractParams as BoostListExtractParams
from .boost_list_generate_params import BoostListGenerateParams as BoostListGenerateParams
from .streaming_get_url_response import StreamingGetURLResponse as StreamingGetURLResponse
from .boost_list_extract_response import BoostListExtractResponse as BoostListExtractResponse
from .transcription_create_params import TranscriptionCreateParams as TranscriptionCreateParams
from .boost_list_generate_response import BoostListGenerateResponse as BoostListGenerateResponse
from .transcription_create_response import TranscriptionCreateResponse as TranscriptionCreateResponse
from .transcription_retrieve_response import TranscriptionRetrieveResponse as TranscriptionRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from .subscriptions import (
    SubscriptionsResource,
    AsyncSubscriptionsResource,
    SubscriptionsResourceWithRawResponse,
    AsyncSubscriptionsResourceWithRawResponse,
    SubscriptionsResourceWithStreamingResponse,
    AsyncSubscriptionsResourceWithStreamingResponse,
)

__all__ = ["EventsResource", "AsyncEventsResource"]


class EventsResource(SyncAPIResource):
    @cached_property
    def subscriptions(self) -> SubscriptionsResource:
        """Secure document storage with semantic search and GraphRAG"""
        return SubscriptionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> EventsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return EventsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EventsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return EventsResourceWithStreamingResponse(self)


class AsyncEventsResource(AsyncAPIResource):
    @cached_property
    def subscriptions(self) -> AsyncSubscriptionsResource:
        """Secure document storage with semantic search and GraphRAG"""
        return AsyncSubscriptionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncEventsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEventsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEventsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncEventsResourceWithStreamingResponse(self)


class EventsResourceWithRawResponse:
    def __init__(self, events: EventsResource) -> None:
        self._events = events

    @cached_property
    def subscriptions(self) -> SubscriptionsResourceWithRawResponse:
        """Secure document storage with semantic search and GraphRAG"""
        return SubscriptionsResourceWithRawResponse(self._events.subscriptions)


class AsyncEventsResourceWithRawResponse:
    def __init__(self, events: AsyncEventsResource) -> None:
        self._events = events

    @cached_property
    def subscriptions(self) -> AsyncSubscriptionsResourceWithRawResponse:
        """Secure document storage with semantic search and GraphRAG"""
        return AsyncSubscriptionsResourceWithRawResponse(self._events.subscriptions)


class EventsResourceWithStreamingResponse:
    def __init__(self, events: EventsResource) -> None:
        self._events = events

    @cached_property
    def subscriptions(self) -> SubscriptionsResourceWithStreamingResponse:
        """Secure document storage with semantic search and GraphRAG"""
        return SubscriptionsResourceWithStreamingResponse(self._events.subscriptions)


class AsyncEventsResourceWithStreamingResponse:
    def __init__(self, events: AsyncEventsResource) -> None:
        self._events = events

    @cached_property
    def subscriptions(self) -> AsyncSubscriptionsResourceWithStreamingResponse:
        """Secure document storage with semantic search and GraphRAG"""
        return AsyncSubscriptionsResourceWithStreamingResponse(self._events.subscriptions)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["V1RetrieveResponse"]


class V1RetrieveResponse(BaseModel):
    id: str
    """OCR job ID"""

    created_at: datetime
    """Job creation timestamp"""

    status: Literal["pending", "processing", "completed", "failed"]
    """Current job status"""

    completed_at: Optional[datetime] = None
    """Job completion timestamp"""

    metadata: Optional[object] = None
    """Additional processing metadata"""

    page_count: Optional[int] = None
    """Number of pages processed"""

    text: Optional[str] = None
    """Extracted text content (when completed)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from ...._types import SequenceNotStr
from ...._utils import PropertyInfo

__all__ = ["AgentUpdateParams"]


class AgentUpdateParams(TypedDict, total=False):
    description: Optional[str]
    """Updated agent description. Pass null to clear if supported by the client."""

    disabled_tools: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="disabledTools")]
    """Denylist of tools the agent cannot use.

    Mutually exclusive with enabledTools — set one or the other, not both. Pass null
    to clear.
    """

    enabled_tools: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="enabledTools")]
    """Allowlist of tools the agent can use.

    Mutually exclusive with disabledTools — set one or the other, not both. Pass
    null to clear.
    """

    instructions: str
    """Updated system instructions that guide agent behavior"""

    model: str
    """Model identifier the agent should use for future runs"""

    name: str
    """Updated agent display name"""

    sandbox: Optional[object]
    """Sandbox configuration override for future agent runs. Pass null to clear."""

    vault_groups: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="vaultGroups")]
    """Vault group IDs the agent can access. Pass null to clear."""

    vault_ids: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="vaultIds")]
    """Vault IDs the agent can access directly. Pass null to clear."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.compute.v1.instance_type_list_response import InstanceTypeListResponse

__all__ = ["InstanceTypesResource", "AsyncInstanceTypesResource"]


class InstanceTypesResource(SyncAPIResource):
    """Serverless GPU and CPU infrastructure"""

    @cached_property
    def with_raw_response(self) -> InstanceTypesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return InstanceTypesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> InstanceTypesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return InstanceTypesResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InstanceTypeListResponse:
        """
        Retrieves all available GPU instance types with pricing, specifications, and
        regional availability. Includes T4, A10, A100, H100, and H200 GPUs powered by
        Lambda Labs. Perfect for AI model training, inference workloads, and legal
        document OCR processing at scale.
        """
        return self._get(
            "/compute/v1/instance-types",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InstanceTypeListResponse,
        )


class AsyncInstanceTypesResource(AsyncAPIResource):
    """Serverless GPU and CPU infrastructure"""

    @cached_property
    def with_raw_response(self) -> AsyncInstanceTypesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncInstanceTypesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncInstanceTypesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncInstanceTypesResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InstanceTypeListResponse:
        """
        Retrieves all available GPU instance types with pricing, specifications, and
        regional availability. Includes T4, A10, A100, H100, and H200 GPUs powered by
        Lambda Labs. Perfect for AI model training, inference workloads, and legal
        document OCR processing at scale.
        """
        return await self._get(
            "/compute/v1/instance-types",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=InstanceTypeListResponse,
        )


class InstanceTypesResourceWithRawResponse:
    def __init__(self, instance_types: InstanceTypesResource) -> None:
        self._instance_types = instance_types

        self.list = to_raw_response_wrapper(
            instance_types.list,
        )


class AsyncInstanceTypesResourceWithRawResponse:
    def __init__(self, instance_types: AsyncInstanceTypesResource) -> None:
        self._instance_types = instance_types

        self.list = async_to_raw_response_wrapper(
            instance_types.list,
        )


class InstanceTypesResourceWithStreamingResponse:
    def __init__(self, instance_types: InstanceTypesResource) -> None:
        self._instance_types = instance_types

        self.list = to_streamed_response_wrapper(
            instance_types.list,
        )


class AsyncInstanceTypesResourceWithStreamingResponse:
    def __init__(self, instance_types: AsyncInstanceTypesResource) -> None:
        self._instance_types = instance_types

        self.list = async_to_streamed_response_wrapper(
            instance_types.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["V1CreateEmbeddingResponse", "Data", "Usage"]


class Data(BaseModel):
    embedding: Optional[List[float]] = None

    index: Optional[int] = None

    object: Optional[str] = None


class Usage(BaseModel):
    prompt_tokens: Optional[int] = None

    total_tokens: Optional[int] = None


class V1CreateEmbeddingResponse(BaseModel):
    data: Optional[List[Data]] = None

    model: Optional[str] = None

    object: Optional[str] = None

    usage: Optional[Usage] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["SkillReadResponse"]


class SkillReadResponse(BaseModel):
    author_name: Optional[str] = None
    """Skill author"""

    content: Optional[str] = None
    """Full skill content in markdown"""

    license: Optional[str] = None
    """Skill license"""

    metadata: Optional[object] = None
    """Custom metadata (custom skills only)"""

    name: Optional[str] = None
    """Skill name"""

    slug: Optional[str] = None
    """Unique skill identifier"""

    source: Optional[Literal["curated", "custom"]] = None
    """Skill source (authenticated requests only)"""

    summary: Optional[str] = None
    """Brief skill description"""

    tags: Optional[List[str]] = None
    """Skill tags"""

    version: Optional[str] = None
    """Skill version"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .agent import (
    AgentResource,
    AsyncAgentResource,
    AgentResourceWithRawResponse,
    AsyncAgentResourceWithRawResponse,
    AgentResourceWithStreamingResponse,
    AsyncAgentResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
    "AgentResource",
    "AsyncAgentResource",
    "AgentResourceWithRawResponse",
    "AsyncAgentResourceWithRawResponse",
    "AgentResourceWithStreamingResponse",
    "AsyncAgentResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["CustomListParams"]


class CustomListParams(TypedDict, total=False):
    cursor: str
    """Cursor for pagination (skill ID from previous page)"""

    limit: int
    """Maximum number of results (1-100)"""

    tag: str
    """Filter by tag"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .run_list_params import RunListParams as RunListParams
from .run_watch_params import RunWatchParams as RunWatchParams
from .agent_list_params import AgentListParams as AgentListParams
from .run_create_params import RunCreateParams as RunCreateParams
from .run_events_params import RunEventsParams as RunEventsParams
from .run_exec_response import RunExecResponse as RunExecResponse
from .run_list_response import RunListResponse as RunListResponse
from .chat_create_params import ChatCreateParams as ChatCreateParams
from .chat_stream_params import ChatStreamParams as ChatStreamParams
from .run_watch_response import RunWatchResponse as RunWatchResponse
from .agent_create_params import AgentCreateParams as AgentCreateParams
from .agent_list_response import AgentListResponse as AgentListResponse
from .agent_update_params import AgentUpdateParams as AgentUpdateParams
from .chat_respond_params import ChatRespondParams as ChatRespondParams
from .run_cancel_response import RunCancelResponse as RunCancelResponse
from .run_create_response import RunCreateResponse as RunCreateResponse
from .run_events_response import RunEventsResponse as RunEventsResponse
from .chat_cancel_response import ChatCancelResponse as ChatCancelResponse
from .chat_create_response import ChatCreateResponse as ChatCreateResponse
from .chat_delete_response import ChatDeleteResponse as ChatDeleteResponse
from .chat_stream_response import ChatStreamResponse as ChatStreamResponse
from .agent_create_response import AgentCreateResponse as AgentCreateResponse
from .agent_delete_response import AgentDeleteResponse as AgentDeleteResponse
from .agent_update_response import AgentUpdateResponse as AgentUpdateResponse
from .chat_respond_response import ChatRespondResponse as ChatRespondResponse
from .execute_create_params import ExecuteCreateParams as ExecuteCreateParams
from .agent_retrieve_response import AgentRetrieveResponse as AgentRetrieveResponse
from .execute_create_response import ExecuteCreateResponse as ExecuteCreateResponse
from .run_get_status_response import RunGetStatusResponse as RunGetStatusResponse
from .chat_send_message_params import ChatSendMessageParams as ChatSendMessageParams
from .run_get_details_response import RunGetDetailsResponse as RunGetDetailsResponse
from .chat_reply_to_question_params import ChatReplyToQuestionParams as ChatReplyToQuestionParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from casedev._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        v1 = client.matters.v1.create(
            title="title",
        )
        assert v1 is None

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        v1 = client.matters.v1.create(
            title="title",
            billing={"foo": "bar"},
            client_name="client_name",
            client_party_id="client_party_id",
            custom_fields={"foo": "bar"},
            description="description",
            display_id="display_id",
            important_dates={"foo": "bar"},
            jurisdiction={"foo": "bar"},
            matter_type="matter_type",
            metadata={"foo": "bar"},
            practice_area="practice_area",
            responsible_attorney_id="responsible_attorney_id",
            status="intake",
            subtype="subtype",
            vault={
                "description": "description",
                "enable_graph": True,
                "enable_indexing": True,
                "metadata": {"foo": "bar"},
            },
            vault_id="vault_id",
        )
        assert v1 is None

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.matters.v1.with_raw_response.create(
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert v1 is None

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.matters.v1.with_streaming_response.create(
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Casedev) -> None:
        v1 = client.matters.v1.retrieve(
            "id",
        )
        assert v1 is None

    @parametrize
    def test_raw_response_retrieve(self, client: Casedev) -> None:
        response = client.matters.v1.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert v1 is None

    @parametrize
    def test_streaming_response_retrieve(self, client: Casedev) -> None:
        with client.matters.v1.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_update(self, client: Casedev) -> None:
        v1 = client.matters.v1.update(
            id="id",
        )
        assert v1 is None

    @parametrize
    def test_method_update_with_all_params(self, client: Casedev) -> None:
        v1 = client.matters.v1.update(
            id="id",
            archived_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            billing={"foo": "bar"},
            client_name="client_name",
            client_party_id="client_party_id",
            custom_fields={"foo": "bar"},
            description="description",
            display_id="display_id",
            important_dates={"foo": "bar"},
            jurisdiction={"foo": "bar"},
            matter_type="matter_type",
            metadata={"foo": "bar"},
            practice_area="practice_area",
            responsible_attorney_id="responsible_attorney_id",
            status="intake",
            subtype="subtype",
            title="title",
        )
        assert v1 is None

    @parametrize
    def test_raw_response_update(self, client: Casedev) -> None:
        response = client.matters.v1.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert v1 is None

    @parametrize
    def test_streaming_response_update(self, client: Casedev) -> None:
        with client.matters.v1.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.with_raw_response.update(
                id="",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        v1 = client.matters.v1.list()
        assert v1 is None

    @parametrize
    def test_method_list_with_all_params(self, client: Casedev) -> None:
        v1 = client.matters.v1.list(
            matter_type="matter_type",
            practice_area="practice_area",
            query="query",
            status="status",
        )
        assert v1 is None

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.matters.v1.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert v1 is None

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.matters.v1.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.matters.v1.create(
            title="title",
        )
        assert v1 is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.matters.v1.create(
            title="title",
            billing={"foo": "bar"},
            client_name="client_name",
            client_party_id="client_party_id",
            custom_fields={"foo": "bar"},
            description="description",
            display_id="display_id",
            important_dates={"foo": "bar"},
            jurisdiction={"foo": "bar"},
            matter_type="matter_type",
            metadata={"foo": "bar"},
            practice_area="practice_area",
            responsible_attorney_id="responsible_attorney_id",
            status="intake",
            subtype="subtype",
            vault={
                "description": "description",
                "enable_graph": True,
                "enable_indexing": True,
                "metadata": {"foo": "bar"},
            },
            vault_id="vault_id",
        )
        assert v1 is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.with_raw_response.create(
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert v1 is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.with_streaming_response.create(
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.matters.v1.retrieve(
            "id",
        )
        assert v1 is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert v1 is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.matters.v1.update(
            id="id",
        )
        assert v1 is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.matters.v1.update(
            id="id",
            archived_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            billing={"foo": "bar"},
            client_name="client_name",
            client_party_id="client_party_id",
            custom_fields={"foo": "bar"},
            description="description",
            display_id="display_id",
            important_dates={"foo": "bar"},
            jurisdiction={"foo": "bar"},
            matter_type="matter_type",
            metadata={"foo": "bar"},
            practice_area="practice_area",
            responsible_attorney_id="responsible_attorney_id",
            status="intake",
            subtype="subtype",
            title="title",
        )
        assert v1 is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert v1 is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.with_raw_response.update(
                id="",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.matters.v1.list()
        assert v1 is None

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.matters.v1.list(
            matter_type="matter_type",
            practice_area="practice_area",
            query="query",
            status="status",
        )
        assert v1 is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert v1 is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .events import (
    EventsResource,
    AsyncEventsResource,
    EventsResourceWithRawResponse,
    AsyncEventsResourceWithRawResponse,
    EventsResourceWithStreamingResponse,
    AsyncEventsResourceWithStreamingResponse,
)
from .subscriptions import (
    SubscriptionsResource,
    AsyncSubscriptionsResource,
    SubscriptionsResourceWithRawResponse,
    AsyncSubscriptionsResourceWithRawResponse,
    SubscriptionsResourceWithStreamingResponse,
    AsyncSubscriptionsResourceWithStreamingResponse,
)

__all__ = [
    "SubscriptionsResource",
    "AsyncSubscriptionsResource",
    "SubscriptionsResourceWithRawResponse",
    "AsyncSubscriptionsResourceWithRawResponse",
    "SubscriptionsResourceWithStreamingResponse",
    "AsyncSubscriptionsResourceWithStreamingResponse",
    "EventsResource",
    "AsyncEventsResource",
    "EventsResourceWithRawResponse",
    "AsyncEventsResourceWithRawResponse",
    "EventsResourceWithStreamingResponse",
    "AsyncEventsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ExecuteCreateResponse", "Logs"]


class Logs(BaseModel):
    linc: Optional[str] = None

    runner: Optional[str] = None


class ExecuteCreateResponse(BaseModel):
    agent_id: Optional[str] = FieldInfo(alias="agentId", default=None)

    error: Optional[str] = None

    logs: Optional[Logs] = None

    message: Optional[str] = None

    output: Optional[str] = None

    provider: Optional[Literal["daytona", "vercel"]] = None

    run_id: Optional[str] = FieldInfo(alias="runId", default=None)

    runtime_id: Optional[str] = FieldInfo(alias="runtimeId", default=None)

    runtime_state: Optional[Literal["running", "ended", "error"]] = FieldInfo(alias="runtimeState", default=None)

    status: Optional[Literal["running", "completed", "failed"]] = None

    usage: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = ["FileListResponse", "File"]


class File(BaseModel):
    name: Optional[str] = None

    path: Optional[str] = None
    """Relative path from /workspace"""

    size_bytes: Optional[int] = FieldInfo(alias="sizeBytes", default=None)


class FileListResponse(BaseModel):
    chat_id: Optional[str] = FieldInfo(alias="chatId", default=None)

    files: Optional[List[File]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel

__all__ = ["SystemListServicesResponse", "Service"]


class Service(BaseModel):
    id: str

    description: str

    href: str

    icon: str

    name: str

    order: int


class SystemListServicesResponse(BaseModel):
    services: List[Service]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1VerifyResponse", "Citation", "CitationCandidate", "CitationCase", "CitationSpan", "Summary"]


class CitationCandidate(BaseModel):
    court: Optional[str] = None

    date_decided: Optional[str] = FieldInfo(alias="dateDecided", default=None)

    name: Optional[str] = None

    url: Optional[str] = None


class CitationCase(BaseModel):
    """Case metadata (when verified)"""

    id: Optional[int] = None

    court: Optional[str] = None

    date_decided: Optional[str] = FieldInfo(alias="dateDecided", default=None)

    docket_number: Optional[str] = FieldInfo(alias="docketNumber", default=None)

    name: Optional[str] = None

    parallel_citations: Optional[List[str]] = FieldInfo(alias="parallelCitations", default=None)

    short_name: Optional[str] = FieldInfo(alias="shortName", default=None)

    url: Optional[str] = None


class CitationSpan(BaseModel):
    end: Optional[int] = None

    start: Optional[int] = None


class Citation(BaseModel):
    candidates: Optional[List[CitationCandidate]] = None
    """Multiple candidates (when multiple_matches or heuristic verification)"""

    case: Optional[CitationCase] = None
    """Case metadata (when verified)"""

    confidence: Optional[float] = None
    """Confidence score (1.0 for CourtListener, heuristic score for fallback)."""

    normalized: Optional[str] = None
    """Normalized citation string"""

    original: Optional[str] = None
    """Original citation as found in text"""

    span: Optional[CitationSpan] = None

    status: Optional[Literal["verified", "not_found", "multiple_matches"]] = None

    verification_source: Optional[Literal["courtlistener", "heuristic"]] = FieldInfo(
        alias="verificationSource", default=None
    )
    """Source of verification result (heuristic for fallback matches)."""


class Summary(BaseModel):
    multiple_matches: Optional[int] = FieldInfo(alias="multipleMatches", default=None)
    """Citations with multiple possible matches"""

    not_found: Optional[int] = FieldInfo(alias="notFound", default=None)
    """Citations not found in database"""

    total: Optional[int] = None
    """Total citations found"""

    verified: Optional[int] = None
    """Citations verified against real cases"""


class V1VerifyResponse(BaseModel):
    citations: Optional[List[Citation]] = None

    summary: Optional[Summary] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ProjectGetConnectionResponse"]


class ProjectGetConnectionResponse(BaseModel):
    branch: str
    """Branch name for this connection"""

    connection_uri: str = FieldInfo(alias="connectionUri")
    """PostgreSQL connection string (includes credentials)"""

    pooled: bool
    """Whether this is a pooled connection"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.compute.v1 import (
    SecretListResponse,
    SecretCreateResponse,
    SecretDeleteGroupResponse,
    SecretUpdateGroupResponse,
    SecretRetrieveGroupResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSecrets:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.create(
            name="name",
        )
        assert_matches_type(SecretCreateResponse, secret, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.create(
            name="name",
            description="description",
            env="env",
        )
        assert_matches_type(SecretCreateResponse, secret, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.compute.v1.secrets.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = response.parse()
        assert_matches_type(SecretCreateResponse, secret, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.compute.v1.secrets.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = response.parse()
            assert_matches_type(SecretCreateResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.list()
        assert_matches_type(SecretListResponse, secret, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.list(
            env="env",
        )
        assert_matches_type(SecretListResponse, secret, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.compute.v1.secrets.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = response.parse()
        assert_matches_type(SecretListResponse, secret, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.compute.v1.secrets.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = response.parse()
            assert_matches_type(SecretListResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete_group(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.delete_group(
            group="group",
        )
        assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

    @parametrize
    def test_method_delete_group_with_all_params(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.delete_group(
            group="group",
            env="env",
            key="key",
        )
        assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

    @parametrize
    def test_raw_response_delete_group(self, client: Casedev) -> None:
        response = client.compute.v1.secrets.with_raw_response.delete_group(
            group="group",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = response.parse()
        assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

    @parametrize
    def test_streaming_response_delete_group(self, client: Casedev) -> None:
        with client.compute.v1.secrets.with_streaming_response.delete_group(
            group="group",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = response.parse()
            assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete_group(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            client.compute.v1.secrets.with_raw_response.delete_group(
                group="",
            )

    @parametrize
    def test_method_retrieve_group(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.retrieve_group(
            group="group",
        )
        assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

    @parametrize
    def test_method_retrieve_group_with_all_params(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.retrieve_group(
            group="group",
            env="env",
        )
        assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

    @parametrize
    def test_raw_response_retrieve_group(self, client: Casedev) -> None:
        response = client.compute.v1.secrets.with_raw_response.retrieve_group(
            group="group",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = response.parse()
        assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

    @parametrize
    def test_streaming_response_retrieve_group(self, client: Casedev) -> None:
        with client.compute.v1.secrets.with_streaming_response.retrieve_group(
            group="group",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = response.parse()
            assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve_group(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            client.compute.v1.secrets.with_raw_response.retrieve_group(
                group="",
            )

    @parametrize
    def test_method_update_group(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
        )
        assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

    @parametrize
    def test_method_update_group_with_all_params(self, client: Casedev) -> None:
        secret = client.compute.v1.secrets.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
            env="env",
        )
        assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

    @parametrize
    def test_raw_response_update_group(self, client: Casedev) -> None:
        response = client.compute.v1.secrets.with_raw_response.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = response.parse()
        assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

    @parametrize
    def test_streaming_response_update_group(self, client: Casedev) -> None:
        with client.compute.v1.secrets.with_streaming_response.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = response.parse()
            assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_group(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            client.compute.v1.secrets.with_raw_response.update_group(
                group="",
                secrets={"foo": "string"},
            )


class TestAsyncSecrets:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.create(
            name="name",
        )
        assert_matches_type(SecretCreateResponse, secret, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.create(
            name="name",
            description="description",
            env="env",
        )
        assert_matches_type(SecretCreateResponse, secret, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.compute.v1.secrets.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = await response.parse()
        assert_matches_type(SecretCreateResponse, secret, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.compute.v1.secrets.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = await response.parse()
            assert_matches_type(SecretCreateResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.list()
        assert_matches_type(SecretListResponse, secret, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.list(
            env="env",
        )
        assert_matches_type(SecretListResponse, secret, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.compute.v1.secrets.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = await response.parse()
        assert_matches_type(SecretListResponse, secret, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.compute.v1.secrets.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = await response.parse()
            assert_matches_type(SecretListResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete_group(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.delete_group(
            group="group",
        )
        assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

    @parametrize
    async def test_method_delete_group_with_all_params(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.delete_group(
            group="group",
            env="env",
            key="key",
        )
        assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

    @parametrize
    async def test_raw_response_delete_group(self, async_client: AsyncCasedev) -> None:
        response = await async_client.compute.v1.secrets.with_raw_response.delete_group(
            group="group",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = await response.parse()
        assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

    @parametrize
    async def test_streaming_response_delete_group(self, async_client: AsyncCasedev) -> None:
        async with async_client.compute.v1.secrets.with_streaming_response.delete_group(
            group="group",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = await response.parse()
            assert_matches_type(SecretDeleteGroupResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete_group(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            await async_client.compute.v1.secrets.with_raw_response.delete_group(
                group="",
            )

    @parametrize
    async def test_method_retrieve_group(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.retrieve_group(
            group="group",
        )
        assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

    @parametrize
    async def test_method_retrieve_group_with_all_params(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.retrieve_group(
            group="group",
            env="env",
        )
        assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

    @parametrize
    async def test_raw_response_retrieve_group(self, async_client: AsyncCasedev) -> None:
        response = await async_client.compute.v1.secrets.with_raw_response.retrieve_group(
            group="group",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = await response.parse()
        assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve_group(self, async_client: AsyncCasedev) -> None:
        async with async_client.compute.v1.secrets.with_streaming_response.retrieve_group(
            group="group",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = await response.parse()
            assert_matches_type(SecretRetrieveGroupResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve_group(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            await async_client.compute.v1.secrets.with_raw_response.retrieve_group(
                group="",
            )

    @parametrize
    async def test_method_update_group(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
        )
        assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

    @parametrize
    async def test_method_update_group_with_all_params(self, async_client: AsyncCasedev) -> None:
        secret = await async_client.compute.v1.secrets.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
            env="env",
        )
        assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

    @parametrize
    async def test_raw_response_update_group(self, async_client: AsyncCasedev) -> None:
        response = await async_client.compute.v1.secrets.with_raw_response.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        secret = await response.parse()
        assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

    @parametrize
    async def test_streaming_response_update_group(self, async_client: AsyncCasedev) -> None:
        async with async_client.compute.v1.secrets.with_streaming_response.update_group(
            group="litigation-apis",
            secrets={"foo": "string"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            secret = await response.parse()
            assert_matches_type(SecretUpdateGroupResponse, secret, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_group(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            await async_client.compute.v1.secrets.with_raw_response.update_group(
                group="",
                secrets={"foo": "string"},
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["EnvironmentListResponse", "Environment"]


class Environment(BaseModel):
    id: Optional[str] = None
    """Unique environment identifier"""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Environment creation timestamp"""

    domain: Optional[str] = None
    """Environment domain"""

    is_default: Optional[bool] = FieldInfo(alias="isDefault", default=None)
    """Whether this is the default environment"""

    name: Optional[str] = None
    """Human-readable environment name"""

    slug: Optional[str] = None
    """URL-safe environment identifier"""

    status: Optional[str] = None
    """Environment status"""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Last update timestamp"""


class EnvironmentListResponse(BaseModel):
    environments: Optional[List[Environment]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1GetUsageResponse", "Period", "Pricing", "Project", "ProjectCosts", "Totals"]


class Period(BaseModel):
    end: Optional[datetime] = None
    """End of the billing period"""

    start: Optional[datetime] = None
    """Start of the billing period"""


class Pricing(BaseModel):
    """Current pricing rates"""

    branch_per_month: Optional[float] = FieldInfo(alias="branchPerMonth", default=None)
    """Cost per branch per month in dollars"""

    compute_per_cu_hour: Optional[float] = FieldInfo(alias="computePerCuHour", default=None)
    """Cost per compute unit hour in dollars"""

    free_branches: Optional[int] = FieldInfo(alias="freeBranches", default=None)
    """Number of free branches included"""

    storage_per_gb_month: Optional[float] = FieldInfo(alias="storagePerGbMonth", default=None)
    """Cost per GB of storage per month in dollars"""

    transfer_per_gb: Optional[float] = FieldInfo(alias="transferPerGb", default=None)
    """Cost per GB of data transfer in dollars"""


class ProjectCosts(BaseModel):
    branches: Optional[str] = None

    compute: Optional[str] = None

    storage: Optional[str] = None

    total: Optional[str] = None

    transfer: Optional[str] = None


class Project(BaseModel):
    id: Optional[str] = None

    branch_count: Optional[int] = FieldInfo(alias="branchCount", default=None)

    compute_cu_hours: Optional[float] = FieldInfo(alias="computeCuHours", default=None)

    costs: Optional[ProjectCosts] = None

    last_updated: Optional[datetime] = FieldInfo(alias="lastUpdated", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    project_name: Optional[str] = FieldInfo(alias="projectName", default=None)

    storage_gb_months: Optional[float] = FieldInfo(alias="storageGbMonths", default=None)

    transfer_gb: Optional[float] = FieldInfo(alias="transferGb", default=None)


class Totals(BaseModel):
    """Aggregated totals across all projects"""

    branch_cost_dollars: Optional[str] = FieldInfo(alias="branchCostDollars", default=None)
    """Total branch cost formatted as dollars"""

    compute_cost_dollars: Optional[str] = FieldInfo(alias="computeCostDollars", default=None)
    """Total compute cost formatted as dollars"""

    compute_cu_hours: Optional[float] = FieldInfo(alias="computeCuHours", default=None)
    """Total compute unit hours"""

    storage_cost_dollars: Optional[str] = FieldInfo(alias="storageCostDollars", default=None)
    """Total storage cost formatted as dollars"""

    storage_gb_months: Optional[float] = FieldInfo(alias="storageGbMonths", default=None)
    """Total storage in GB-months"""

    total_branches: Optional[int] = FieldInfo(alias="totalBranches", default=None)
    """Total number of branches"""

    total_cost_dollars: Optional[str] = FieldInfo(alias="totalCostDollars", default=None)
    """Total cost formatted as dollars"""

    transfer_cost_dollars: Optional[str] = FieldInfo(alias="transferCostDollars", default=None)
    """Total transfer cost formatted as dollars"""

    transfer_gb: Optional[float] = FieldInfo(alias="transferGb", default=None)
    """Total data transfer in GB"""


class V1GetUsageResponse(BaseModel):
    period: Optional[Period] = None

    pricing: Optional[Pricing] = None
    """Current pricing rates"""

    project_count: Optional[int] = FieldInfo(alias="projectCount", default=None)
    """Total number of projects with usage"""

    projects: Optional[List[Project]] = None
    """Usage breakdown by project"""

    totals: Optional[Totals] = None
    """Aggregated totals across all projects"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["VaultSearchParams", "Filters"]


class VaultSearchParams(TypedDict, total=False):
    query: Required[str]
    """Search query or question to find relevant documents"""

    filters: Filters
    """Filters to narrow search results to specific documents"""

    method: Literal["vector", "graph", "hybrid", "global", "local", "fast", "entity"]
    """
    Search method: 'global' for comprehensive questions, 'entity' for specific
    entities, 'fast' for quick similarity search, 'hybrid' for combined approach
    """

    top_k: Annotated[int, PropertyInfo(alias="topK")]
    """Maximum number of results to return"""


class Filters(TypedDict, total=False, extra_items=object):  # type: ignore[call-arg]
    """Filters to narrow search results to specific documents"""

    object_id: Union[str, SequenceNotStr[str]]
    """Filter to specific document(s) by object ID.

    Accepts a single ID or array of IDs.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Required, TypedDict

__all__ = ["LogCreateParams"]


class LogCreateParams(TypedDict, total=False):
    summary: Required[str]

    details: Dict[str, object]

    event_type: str

    work_item_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Optional
from datetime import datetime
from typing_extensions import Literal

import httpx

from .log import (
    LogResource,
    AsyncLogResource,
    LogResourceWithRawResponse,
    AsyncLogResourceWithRawResponse,
    LogResourceWithStreamingResponse,
    AsyncLogResourceWithStreamingResponse,
)
from .types import (
    TypesResource,
    AsyncTypesResource,
    TypesResourceWithRawResponse,
    AsyncTypesResourceWithRawResponse,
    TypesResourceWithStreamingResponse,
    AsyncTypesResourceWithStreamingResponse,
)
from .shares import (
    SharesResource,
    AsyncSharesResource,
    SharesResourceWithRawResponse,
    AsyncSharesResourceWithRawResponse,
    SharesResourceWithStreamingResponse,
    AsyncSharesResourceWithStreamingResponse,
)
from .parties import (
    PartiesResource,
    AsyncPartiesResource,
    PartiesResourceWithRawResponse,
    AsyncPartiesResourceWithRawResponse,
    PartiesResourceWithStreamingResponse,
    AsyncPartiesResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from .work_items import (
    WorkItemsResource,
    AsyncWorkItemsResource,
    WorkItemsResourceWithRawResponse,
    AsyncWorkItemsResourceWithRawResponse,
    WorkItemsResourceWithStreamingResponse,
    AsyncWorkItemsResourceWithStreamingResponse,
)
from .agent_types import (
    AgentTypesResource,
    AsyncAgentTypesResource,
    AgentTypesResourceWithRawResponse,
    AsyncAgentTypesResourceWithRawResponse,
    AgentTypesResourceWithStreamingResponse,
    AsyncAgentTypesResourceWithStreamingResponse,
)
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .events.events import (
    EventsResource,
    AsyncEventsResource,
    EventsResourceWithRawResponse,
    AsyncEventsResourceWithRawResponse,
    EventsResourceWithStreamingResponse,
    AsyncEventsResourceWithStreamingResponse,
)
from .matter_parties import (
    MatterPartiesResource,
    AsyncMatterPartiesResource,
    MatterPartiesResourceWithRawResponse,
    AsyncMatterPartiesResourceWithRawResponse,
    MatterPartiesResourceWithStreamingResponse,
    AsyncMatterPartiesResourceWithStreamingResponse,
)
from ...._base_client import make_request_options
from ....types.matters import v1_list_params, v1_create_params, v1_update_params

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def agent_types(self) -> AgentTypesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AgentTypesResource(self._client)

    @cached_property
    def parties(self) -> PartiesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return PartiesResource(self._client)

    @cached_property
    def types(self) -> TypesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return TypesResource(self._client)

    @cached_property
    def events(self) -> EventsResource:
        return EventsResource(self._client)

    @cached_property
    def log(self) -> LogResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return LogResource(self._client)

    @cached_property
    def matter_parties(self) -> MatterPartiesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return MatterPartiesResource(self._client)

    @cached_property
    def shares(self) -> SharesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return SharesResource(self._client)

    @cached_property
    def work_items(self) -> WorkItemsResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return WorkItemsResource(self._client)

    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        title: str,
        billing: Dict[str, object] | Omit = omit,
        client_name: str | Omit = omit,
        client_party_id: Optional[str] | Omit = omit,
        custom_fields: Dict[str, object] | Omit = omit,
        description: str | Omit = omit,
        display_id: str | Omit = omit,
        important_dates: Dict[str, object] | Omit = omit,
        jurisdiction: Dict[str, object] | Omit = omit,
        matter_type: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        practice_area: str | Omit = omit,
        responsible_attorney_id: str | Omit = omit,
        status: Literal["intake", "open", "pending", "closed", "archived"] | Omit = omit,
        subtype: str | Omit = omit,
        vault: v1_create_params.Vault | Omit = omit,
        vault_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a new legal matter and optionally link an existing primary vault.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/matters/v1",
            body=maybe_transform(
                {
                    "title": title,
                    "billing": billing,
                    "client_name": client_name,
                    "client_party_id": client_party_id,
                    "custom_fields": custom_fields,
                    "description": description,
                    "display_id": display_id,
                    "important_dates": important_dates,
                    "jurisdiction": jurisdiction,
                    "matter_type": matter_type,
                    "metadata": metadata,
                    "practice_area": practice_area,
                    "responsible_attorney_id": responsible_attorney_id,
                    "status": status,
                    "subtype": subtype,
                    "vault": vault,
                    "vault_id": vault_id,
                },
                v1_create_params.V1CreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get a single matter by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/matters/v1/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        id: str,
        *,
        archived_at: Union[str, datetime, None] | Omit = omit,
        billing: Dict[str, object] | Omit = omit,
        client_name: str | Omit = omit,
        client_party_id: Optional[str] | Omit = omit,
        custom_fields: Dict[str, object] | Omit = omit,
        description: str | Omit = omit,
        display_id: str | Omit = omit,
        important_dates: Dict[str, object] | Omit = omit,
        jurisdiction: Dict[str, object] | Omit = omit,
        matter_type: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        practice_area: str | Omit = omit,
        responsible_attorney_id: str | Omit = omit,
        status: Literal["intake", "open", "pending", "closed", "archived"] | Omit = omit,
        subtype: str | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update mutable matter fields.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            path_template("/matters/v1/{id}", id=id),
            body=maybe_transform(
                {
                    "archived_at": archived_at,
                    "billing": billing,
                    "client_name": client_name,
                    "client_party_id": client_party_id,
                    "custom_fields": custom_fields,
                    "description": description,
                    "display_id": display_id,
                    "important_dates": important_dates,
                    "jurisdiction": jurisdiction,
                    "matter_type": matter_type,
                    "metadata": metadata,
                    "practice_area": practice_area,
                    "responsible_attorney_id": responsible_attorney_id,
                    "status": status,
                    "subtype": subtype,
                    "title": title,
                },
                v1_update_params.V1UpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        matter_type: str | Omit = omit,
        practice_area: str | Omit = omit,
        query: str | Omit = omit,
        status: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List matters for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/matters/v1",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "matter_type": matter_type,
                        "practice_area": practice_area,
                        "query": query,
                        "status": status,
                    },
                    v1_list_params.V1ListParams,
                ),
            ),
            cast_to=NoneType,
        )


class AsyncV1Resource(AsyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def agent_types(self) -> AsyncAgentTypesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncAgentTypesResource(self._client)

    @cached_property
    def parties(self) -> AsyncPartiesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncPartiesResource(self._client)

    @cached_property
    def types(self) -> AsyncTypesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncTypesResource(self._client)

    @cached_property
    def events(self) -> AsyncEventsResource:
        return AsyncEventsResource(self._client)

    @cached_property
    def log(self) -> AsyncLogResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncLogResource(self._client)

    @cached_property
    def matter_parties(self) -> AsyncMatterPartiesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncMatterPartiesResource(self._client)

    @cached_property
    def shares(self) -> AsyncSharesResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncSharesResource(self._client)

    @cached_property
    def work_items(self) -> AsyncWorkItemsResource:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncWorkItemsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        title: str,
        billing: Dict[str, object] | Omit = omit,
        client_name: str | Omit = omit,
        client_party_id: Optional[str] | Omit = omit,
        custom_fields: Dict[str, object] | Omit = omit,
        description: str | Omit = omit,
        display_id: str | Omit = omit,
        important_dates: Dict[str, object] | Omit = omit,
        jurisdiction: Dict[str, object] | Omit = omit,
        matter_type: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        practice_area: str | Omit = omit,
        responsible_attorney_id: str | Omit = omit,
        status: Literal["intake", "open", "pending", "closed", "archived"] | Omit = omit,
        subtype: str | Omit = omit,
        vault: v1_create_params.Vault | Omit = omit,
        vault_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a new legal matter and optionally link an existing primary vault.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/matters/v1",
            body=await async_maybe_transform(
                {
                    "title": title,
                    "billing": billing,
                    "client_name": client_name,
                    "client_party_id": client_party_id,
                    "custom_fields": custom_fields,
                    "description": description,
                    "display_id": display_id,
                    "important_dates": important_dates,
                    "jurisdiction": jurisdiction,
                    "matter_type": matter_type,
                    "metadata": metadata,
                    "practice_area": practice_area,
                    "responsible_attorney_id": responsible_attorney_id,
                    "status": status,
                    "subtype": subtype,
                    "vault": vault,
                    "vault_id": vault_id,
                },
                v1_create_params.V1CreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get a single matter by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/matters/v1/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        id: str,
        *,
        archived_at: Union[str, datetime, None] | Omit = omit,
        billing: Dict[str, object] | Omit = omit,
        client_name: str | Omit = omit,
        client_party_id: Optional[str] | Omit = omit,
        custom_fields: Dict[str, object] | Omit = omit,
        description: str | Omit = omit,
        display_id: str | Omit = omit,
        important_dates: Dict[str, object] | Omit = omit,
        jurisdiction: Dict[str, object] | Omit = omit,
        matter_type: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        practice_area: str | Omit = omit,
        responsible_attorney_id: str | Omit = omit,
        status: Literal["intake", "open", "pending", "closed", "archived"] | Omit = omit,
        subtype: str | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update mutable matter fields.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            path_template("/matters/v1/{id}", id=id),
            body=await async_maybe_transform(
                {
                    "archived_at": archived_at,
                    "billing": billing,
                    "client_name": client_name,
                    "client_party_id": client_party_id,
                    "custom_fields": custom_fields,
                    "description": description,
                    "display_id": display_id,
                    "important_dates": important_dates,
                    "jurisdiction": jurisdiction,
                    "matter_type": matter_type,
                    "metadata": metadata,
                    "practice_area": practice_area,
                    "responsible_attorney_id": responsible_attorney_id,
                    "status": status,
                    "subtype": subtype,
                    "title": title,
                },
                v1_update_params.V1UpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        matter_type: str | Omit = omit,
        practice_area: str | Omit = omit,
        query: str | Omit = omit,
        status: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List matters for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/matters/v1",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "matter_type": matter_type,
                        "practice_area": practice_area,
                        "query": query,
                        "status": status,
                    },
                    v1_list_params.V1ListParams,
                ),
            ),
            cast_to=NoneType,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.create = to_raw_response_wrapper(
            v1.create,
        )
        self.retrieve = to_raw_response_wrapper(
            v1.retrieve,
        )
        self.update = to_raw_response_wrapper(
            v1.update,
        )
        self.list = to_raw_response_wrapper(
            v1.list,
        )

    @cached_property
    def agent_types(self) -> AgentTypesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AgentTypesResourceWithRawResponse(self._v1.agent_types)

    @cached_property
    def parties(self) -> PartiesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return PartiesResourceWithRawResponse(self._v1.parties)

    @cached_property
    def types(self) -> TypesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return TypesResourceWithRawResponse(self._v1.types)

    @cached_property
    def events(self) -> EventsResourceWithRawResponse:
        return EventsResourceWithRawResponse(self._v1.events)

    @cached_property
    def log(self) -> LogResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return LogResourceWithRawResponse(self._v1.log)

    @cached_property
    def matter_parties(self) -> MatterPartiesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return MatterPartiesResourceWithRawResponse(self._v1.matter_parties)

    @cached_property
    def shares(self) -> SharesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return SharesResourceWithRawResponse(self._v1.shares)

    @cached_property
    def work_items(self) -> WorkItemsResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return WorkItemsResourceWithRawResponse(self._v1.work_items)


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.create = async_to_raw_response_wrapper(
            v1.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            v1.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            v1.update,
        )
        self.list = async_to_raw_response_wrapper(
            v1.list,
        )

    @cached_property
    def agent_types(self) -> AsyncAgentTypesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncAgentTypesResourceWithRawResponse(self._v1.agent_types)

    @cached_property
    def parties(self) -> AsyncPartiesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncPartiesResourceWithRawResponse(self._v1.parties)

    @cached_property
    def types(self) -> AsyncTypesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncTypesResourceWithRawResponse(self._v1.types)

    @cached_property
    def events(self) -> AsyncEventsResourceWithRawResponse:
        return AsyncEventsResourceWithRawResponse(self._v1.events)

    @cached_property
    def log(self) -> AsyncLogResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncLogResourceWithRawResponse(self._v1.log)

    @cached_property
    def matter_parties(self) -> AsyncMatterPartiesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncMatterPartiesResourceWithRawResponse(self._v1.matter_parties)

    @cached_property
    def shares(self) -> AsyncSharesResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncSharesResourceWithRawResponse(self._v1.shares)

    @cached_property
    def work_items(self) -> AsyncWorkItemsResourceWithRawResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncWorkItemsResourceWithRawResponse(self._v1.work_items)


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.create = to_streamed_response_wrapper(
            v1.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            v1.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            v1.update,
        )
        self.list = to_streamed_response_wrapper(
            v1.list,
        )

    @cached_property
    def agent_types(self) -> AgentTypesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AgentTypesResourceWithStreamingResponse(self._v1.agent_types)

    @cached_property
    def parties(self) -> PartiesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return PartiesResourceWithStreamingResponse(self._v1.parties)

    @cached_property
    def types(self) -> TypesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return TypesResourceWithStreamingResponse(self._v1.types)

    @cached_property
    def events(self) -> EventsResourceWithStreamingResponse:
        return EventsResourceWithStreamingResponse(self._v1.events)

    @cached_property
    def log(self) -> LogResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return LogResourceWithStreamingResponse(self._v1.log)

    @cached_property
    def matter_parties(self) -> MatterPartiesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return MatterPartiesResourceWithStreamingResponse(self._v1.matter_parties)

    @cached_property
    def shares(self) -> SharesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return SharesResourceWithStreamingResponse(self._v1.shares)

    @cached_property
    def work_items(self) -> WorkItemsResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return WorkItemsResourceWithStreamingResponse(self._v1.work_items)


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.create = async_to_streamed_response_wrapper(
            v1.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            v1.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            v1.update,
        )
        self.list = async_to_streamed_response_wrapper(
            v1.list,
        )

    @cached_property
    def agent_types(self) -> AsyncAgentTypesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncAgentTypesResourceWithStreamingResponse(self._v1.agent_types)

    @cached_property
    def parties(self) -> AsyncPartiesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncPartiesResourceWithStreamingResponse(self._v1.parties)

    @cached_property
    def types(self) -> AsyncTypesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncTypesResourceWithStreamingResponse(self._v1.types)

    @cached_property
    def events(self) -> AsyncEventsResourceWithStreamingResponse:
        return AsyncEventsResourceWithStreamingResponse(self._v1.events)

    @cached_property
    def log(self) -> AsyncLogResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncLogResourceWithStreamingResponse(self._v1.log)

    @cached_property
    def matter_parties(self) -> AsyncMatterPartiesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncMatterPartiesResourceWithStreamingResponse(self._v1.matter_parties)

    @cached_property
    def shares(self) -> AsyncSharesResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncSharesResourceWithStreamingResponse(self._v1.shares)

    @cached_property
    def work_items(self) -> AsyncWorkItemsResourceWithStreamingResponse:
        """Matter-native legal workspaces and orchestration primitives"""
        return AsyncWorkItemsResourceWithStreamingResponse(self._v1.work_items)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["ProjectListDeploymentsParams"]


class ProjectListDeploymentsParams(TypedDict, total=False):
    limit: float
    """Maximum number of deployments to return"""

    state: str
    """Deployment state to filter by"""

    target: Literal["production", "staging"]
    """Deployment target to filter by"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.matters.v1 import matter_party_create_params

__all__ = ["MatterPartiesResource", "AsyncMatterPartiesResource"]


class MatterPartiesResource(SyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def with_raw_response(self) -> MatterPartiesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return MatterPartiesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MatterPartiesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return MatterPartiesResourceWithStreamingResponse(self)

    def create(
        self,
        id: str,
        *,
        party_id: str,
        role: Literal[
            "client",
            "prospect",
            "opposing_party",
            "opposing_counsel",
            "co_counsel",
            "judge",
            "expert",
            "witness",
            "vendor",
            "insurer",
            "other",
        ],
        custom_fields: Optional[Dict[str, object]] | Omit = omit,
        is_primary: bool | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        notes: Optional[str] | Omit = omit,
        set_as_client: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Attach a reusable party to a matter with a matter-specific role.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            path_template("/matters/v1/{id}/parties", id=id),
            body=maybe_transform(
                {
                    "party_id": party_id,
                    "role": role,
                    "custom_fields": custom_fields,
                    "is_primary": is_primary,
                    "metadata": metadata,
                    "notes": notes,
                    "set_as_client": set_as_client,
                },
                matter_party_create_params.MatterPartyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List parties attached to a matter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/matters/v1/{id}/parties", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncMatterPartiesResource(AsyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def with_raw_response(self) -> AsyncMatterPartiesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMatterPartiesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMatterPartiesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncMatterPartiesResourceWithStreamingResponse(self)

    async def create(
        self,
        id: str,
        *,
        party_id: str,
        role: Literal[
            "client",
            "prospect",
            "opposing_party",
            "opposing_counsel",
            "co_counsel",
            "judge",
            "expert",
            "witness",
            "vendor",
            "insurer",
            "other",
        ],
        custom_fields: Optional[Dict[str, object]] | Omit = omit,
        is_primary: bool | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        notes: Optional[str] | Omit = omit,
        set_as_client: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Attach a reusable party to a matter with a matter-specific role.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            path_template("/matters/v1/{id}/parties", id=id),
            body=await async_maybe_transform(
                {
                    "party_id": party_id,
                    "role": role,
                    "custom_fields": custom_fields,
                    "is_primary": is_primary,
                    "metadata": metadata,
                    "notes": notes,
                    "set_as_client": set_as_client,
                },
                matter_party_create_params.MatterPartyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List parties attached to a matter.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/matters/v1/{id}/parties", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class MatterPartiesResourceWithRawResponse:
    def __init__(self, matter_parties: MatterPartiesResource) -> None:
        self._matter_parties = matter_parties

        self.create = to_raw_response_wrapper(
            matter_parties.create,
        )
        self.list = to_raw_response_wrapper(
            matter_parties.list,
        )


class AsyncMatterPartiesResourceWithRawResponse:
    def __init__(self, matter_parties: AsyncMatterPartiesResource) -> None:
        self._matter_parties = matter_parties

        self.create = async_to_raw_response_wrapper(
            matter_parties.create,
        )
        self.list = async_to_raw_response_wrapper(
            matter_parties.list,
        )


class MatterPartiesResourceWithStreamingResponse:
    def __init__(self, matter_parties: MatterPartiesResource) -> None:
        self._matter_parties = matter_parties

        self.create = to_streamed_response_wrapper(
            matter_parties.create,
        )
        self.list = to_streamed_response_wrapper(
            matter_parties.list,
        )


class AsyncMatterPartiesResourceWithStreamingResponse:
    def __init__(self, matter_parties: AsyncMatterPartiesResource) -> None:
        self._matter_parties = matter_parties

        self.create = async_to_streamed_response_wrapper(
            matter_parties.create,
        )
        self.list = async_to_streamed_response_wrapper(
            matter_parties.list,
        )
